@@ -5,11 +5,11 @@ var path = require('path');
 var spawn = require('child_process').spawn;
 var util = require('util');
 var mkdirp = require('mkdirp');
-var bitcore = require('bitcore-lib');
+var bitcore = require('bitcore-lib-thought');
 var zmq = require('zmq');
 var async = require('async');
 var LRU = require('lru-cache');
-var BitcoinRPC = require('bitcoind-rpc');
+var BitcoinRPC = require('bitcoind-rpc-thought');
 var $ = bitcore.util.preconditions;
 var _  = bitcore.deps._;
 var Transaction = bitcore.Transaction;
